
set ANLAGE; # Menge der Anlagen
set PROD; # Menge der Durchmesser

param kap{ANLAGE} >= 0; # Kapazitt der Anlagen
param kosten{ANLAGE} >= 0; # Kosten der Anlagen
param db{PROD} >= 0; # Deckungsbeitrag der Produkte
param nachfr{PROD} >= 0; # Nachfrage an Produkte
param prodrat{ANLAGE,PROD} >= 0; # Produktionsrate: Walzgeschw.*60/1000
param maxu >= 0; # maximale berstundenanzahl, kann auch als Array ber alle Anlagen deklariert werden
param kostu >= 0; # Kosten der berstunden pro Anlage, kann auch als Array ber alle Anlagen deklariert werden 
param prozent >= 0; # Prozentangabe: berschreitung der Nachfrage

var x{i in ANLAGE,j in PROD} >=0; # Anzahl Stunden, whrend Anlage i Produkt j produziert

var xprod{j in PROD} >= nachfr[j], <=prozent*nachfr[j]; # produzierte Menge des Produkts j

var uebst{i in ANLAGE} >=0, <= maxu; # Anzahl der berstunden

# Modell

#Zielfunktion: Maximierung des Gewinns
maximize Gewinn: sum{j in PROD} db[j]*xprod[j] - sum{i in ANLAGE,j in PROD} kosten[i]*x[i,j] -
         sum{i in ANLAGE} kostu*uebst[i];

# Restriktionen

# Kapazitten der Anlagen
s.t. Kapazitt {i in ANLAGE}: sum{j in PROD} x[i,j] - uebst[i] <= kap[i] ;

# Erzeugung der Produkte
s.t. Erzeugung {j in PROD}: sum{i in ANLAGE} prodrat[i,j]*x[i,j] = xprod[j];
 